+ ====================================================================
+ --------------------------------------------------------------------
+ Version 4: BitSetter support from core grbl
+
+ Version 5; Date 05/08/2024; by Allen Segura; to add comments for
+ Carbide Motion (CM) Status line display. Posted to CM Forum.
+
+ Version 5a; Date 05/11/2024; by Allen Segura, update to add safe Z
+ rapid moves after tool change similar to Carbide Create (CC) v7. 
+ Also updated Vectric PostP displayed.
+ Tested on Shapeoko Pro XXL, CM v635, Vectric Vcarve v12.006.
+
+ --------------------------------------------------------------------
+ ====================================================================


+------------------------------------------------
+    Housekeeping Settings
+------------------------------------------------

POST_NAME = "Carbide Motion ATC (mm) (*.nc) v5a"
FILE_EXTENSION = "gcode"
UNITS = "MM"
DIRECT_OUTPUT = "VTransfer"
LASER_SUPPORT = "YES"

+------------------------------------------------
+    Line terminating characters
+------------------------------------------------

LINE_ENDING = "[13][10]"

+------------------------------------------------
+    Block numbering
+------------------------------------------------

LINE_NUMBER_START     = 0
LINE_NUMBER_INCREMENT = 10
LINE_NUMBER_MAXIMUM = 999999

+================================================
+
+    Formatting for variables
+
+================================================

VAR LINE_NUMBER = [N|A|N|1.0]
VAR DWELL_TIME = [DWELL|A|P|1.2]
VAR POWER = [P|C|S|1.0|10.0]
VAR SPINDLE_SPEED = [S|A|S|1.0]
VAR FEED_RATE = [F|C|F|1.1]
VAR X_POSITION = [X|C|X|1.3]
VAR Y_POSITION = [Y|C|Y|1.3]
VAR Z_POSITION = [Z|C|Z|1.3]
VAR X_HOME_POSITION = [XH|A|X|1.3]
VAR Y_HOME_POSITION = [YH|A|Y|1.3]
VAR Z_HOME_POSITION = [ZH|A|Z|1.3]
VAR ARC_CENTRE_I_INC_POSITION = [I|A|I|1.3]
VAR ARC_CENTRE_J_INC_POSITION = [J|A|J|1.3]


+================================================
+
+    Block definitions for toolpath output
+
+================================================

begin REVISION_COMMENT

"(VECTRIC POSTP: Carbide Motion ATC mm *.nc v5a)"
+"([REVISION])"


+---------------------------------------------------
+  Commands output at the start of the file
+---------------------------------------------------

begin HEADER

"T1"
"G17"
"G21"
"G90"
"M6 T[T]"

"(Move to safe Z to avoid workholding)"
"G53G0Z-0.197"

"(Toolpath: [TOOLPATH_NAME]; Tool #[T])"

"G0[XH][YH]"


+---------------------------------------------
+  Commands output for new segment
+---------------------------------------------

begin NEW_SEGMENT

+"(JUST A PLACEHOLDER COMMENT)"

"(Toolpath: [TOOLPATH_NAME]; Tool #[T])"


+---------------------------------------------------
+  Command output after the header to switch spindle on
+---------------------------------------------------

begin SPINDLE_ON

"[S]M3"


+---------------------------------------------
+  Commands output for a dwell move
+---------------------------------------------

begin DWELL_MOVE

"G4[DWELL]"

+---------------------------------------------------
+  Commands output for tool change
+---------------------------------------------------

begin TOOLCHANGE

"M5"

"(Move to safe Z to avoid workholding)"
"G53G0Z-0.197"

"M6 T[T]"
"[S]M3"


+---------------------------------------------------
+  Commands output for rapid moves
+---------------------------------------------------

begin RAPID_MOVE

"G0[X][Y][Z]"


+---------------------------------------------------
+  Commands output for the plunge move
+---------------------------------------------------

begin PLUNGE_MOVE

"G1[X][Y][Z][F]"


+---------------------------------------------------
+  Commands output for the first feed rate move
+---------------------------------------------------

begin FIRST_FEED_MOVE

"G1[X][Y][Z][F]"


+---------------------------------------------------
+  Commands output for feed rate moves
+---------------------------------------------------

begin FEED_MOVE

"G1[X][Y][Z]"


+---------------------------------------------------
+  Commands output for the first clockwise arc move
+---------------------------------------------------

begin FIRST_CW_ARC_MOVE

"G2[X][Y][I][J][F]"


+---------------------------------------------------
+  Commands output for clockwise arc  move
+---------------------------------------------------

begin CW_ARC_MOVE

"G2[X][Y][I][J]"


+---------------------------------------------------
+  Commands output for the first counterclockwise arc move
+---------------------------------------------------

begin FIRST_CCW_ARC_MOVE

"G3[X][Y][I][J][F]"


+---------------------------------------------------
+  Commands output for counterclockwise arc  move
+---------------------------------------------------

begin CCW_ARC_MOVE

"G3[X][Y][I][J]"


+---------------------------------------------------
+  Commands output when the jet is turned on
+---------------------------------------------------

begin JET_TOOL_ON

"[P]M4"


+---------------------------------------------------
+  Commands output when the jet is turned off
+---------------------------------------------------

begin JET_TOOL_OFF

"M5"


+---------------------------------------------------
+  Commands output when the jet power is changed
+---------------------------------------------------

begin JET_TOOL_POWER
"[P]M4"


+---------------------------------------------------
+  Commands output at the end of the file
+---------------------------------------------------

begin FOOTER

"M5"
"(Toolpath: Toolpaths COMPLETE)"
"G0[ZH]"
"G0[XH][YH]"
"M2"
